| r2rtf_HAMD17 | R Documentation |
A dataset prepared by the Drug Information Association scientific working group to investigate a drug to reduce lower back pain.
r2rtf_HAMD17
A data frame with 831 rows and 6 variables.
This dataset was prepared by the Drug Information Association (DIA) scientific working group to investigate methods for handling missing data. It contains data from an efficacy clinical trial evaluating a drug to reduce lower back pain.
Drug Information Association (DIA) scientific working group on missing data
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.