write_docx: Write an RTF Table or Figure to a DOCX File

View source: R/write_rtf.R

write_docxR Documentation

Write an RTF Table or Figure to a DOCX File

Description

The write_docx function writes an RTF encoding string to a .docx file by first writing to a temporary RTF file and then converting it to DOCX using LibreOffice.

Usage

write_docx(rtf, file)

Arguments

rtf

A character rtf encoding string rendered by rtf_encode().

file

A character string naming a file to save docx file.

Details

This function requires LibreOffice to be installed on the system. The function uses the internal rtf_convert_format() function to perform the conversion from RTF to DOCX format.

Currently only Unix/Linux/macOS systems are supported.

Specification

The contents of this section are shown in PDF user manual only.


r2rtf documentation built on June 10, 2026, 9:07 a.m.