| write_docx | R Documentation |
The write_docx function writes an RTF encoding string to a .docx file by first writing to a temporary RTF file and then converting it to DOCX using LibreOffice.
write_docx(rtf, file)
rtf |
A character rtf encoding string rendered by |
file |
A character string naming a file to save docx file. |
This function requires LibreOffice to be installed on the system.
The function uses the internal rtf_convert_format() function
to perform the conversion from RTF to DOCX format.
Currently only Unix/Linux/macOS systems are supported.
The contents of this section are shown in PDF user manual only.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.